package com.shixing.sxedit;

/**
 * SXMediaTrack 的音频操作对象
 * <p>
 * 只有通过视频文件创建的 {@link SXMediaTrack} 能获取到
 * </p>
 *
 * */
public class SXAudio {

    protected long mNativeManager;
    protected String mTrackID;
    protected int mTrackType;
    protected SXTrack.SXTrackOwnType mOwnType;

    public SXAudio(String trackId, long manager, SXTrack.SXTrackOwnType type) {
        mNativeManager = manager;
        mTrackID = trackId;
        mOwnType = type;
        mTrackType = SXTrack.SX_TRACK_TYPE_AUDIO;
    }

    /**
     * 设置淡入时长
     *
     * @param fadeIn 时长，单位为秒
     */
    public void setFadeInDuration(double fadeIn) {
        nSetFadeInDuration(mNativeManager, mOwnType.value, mTrackID, fadeIn);
    }

    /**
     * 设置淡出时长
     *
     * @param fadeOut 时长，单位为秒
     */
    public void setFadeOutDuration(double fadeOut) {
        nSetFadeOutDuration(mNativeManager, mOwnType.value, mTrackID, fadeOut);
    }

    /**
     * 设置音量大小，默认音量为1
     *
     * @param volume 音量
     */
    public void setVolume(float volume) {
        nSetVolume(mNativeManager, mOwnType.value, mTrackID, volume);
    }

    /**
     * 设置音调大小，默认值为1
     *
     * @param pitch 音调大小
     */
    public void setPitch(float pitch) {
        nSetPitch(mNativeManager, mOwnType.value, mTrackID, pitch);
    }

    /**
     * 获取淡入时长
     *
     * @return 单位为秒
     */
    public double getFadeInDuration() {
        return nFadeInDuration(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 获取淡出时长
     * @return 单位为秒
     */
    public double getFadeOutDuration() {
        return nFadeOutDuration(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 获取音量
     * @return 音量
     */
    public float getVolume() {
        return nVolume(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 获取音调
     * @return 音调
     */
    public float getPitch() {
        return nPitch(mNativeManager, mOwnType.value, mTrackID);
    }

    native static void nSetFadeInDuration(long nativeManager, int type, String trackID, double fadeIn);
    native static void nSetFadeOutDuration(long nativeManager, int type, String trackID, double fadeOut);
    native static void nSetVolume(long nativeManager, int type,  String trackID, float volume);
    native static void nSetPitch(long nativeManager, int type, String trackID, float pitch);

    native static double nFadeInDuration(long nativeManager, int type, String trackID);
    native static double nFadeOutDuration(long nativeManager, int type, String trackID);
    native static float nVolume(long nativeManager, int type, String trackID);
    native static float nPitch(long nativeManager, int type, String trackID);

}
