package com.shixing.sxedit;
/**
 * 音频轨道
 * */
public class SXAudioTrack extends SXTrack {

    public SXAudioTrack(long track, long manager, SXTrackOwnType type) {
        super(track, manager, type);
        mTrackType = SX_TRACK_TYPE_AUDIO;
    }

    /**
     * 设置淡入时长
     *
     * @param fadeIn 时长，单位为秒
     */
    public void setFadeInDuration(double fadeIn) {
        nSetFadeInDuration(mNativeManager, mOwnType.value, mTrackID, fadeIn);
    }

    /**
     * 设置淡出时长
     *
     * @param fadeOut 时长，单位为秒
     */
    public void setFadeOutDuration(double fadeOut) {
        nSetFadeOutDuration(mNativeManager, mOwnType.value, mTrackID, fadeOut);
    }

    /**
     * 设置音量大小，默认音量为1
     *
     * @param volume 音量
     */
    public void setVolume(float volume) {
        nSetVolume(mNativeManager, mOwnType.value, mTrackID, volume);
    }

    /**
     * 设置音频速度，默认值为1
     *
     * @param speed 速度
     */
    public void setSpeed(float speed) {
        nSetSpeed(mNativeManager, mOwnType.value, mTrackID, speed);
    }

    /**
     * 设置音调大小，默认值为1
     *
     * @param pitch 音调大小
     */
    public void setPitch(float pitch) {
        nSetPitch(mNativeManager, mOwnType.value, mTrackID, pitch);
    }

    /**
     * 获取淡入时长
     *
     * @return 单位为秒
     */
    public double getFadeInDuration() {
        return nFadeInDuration(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 获取淡出时长
     * @return 单位为秒
     */
    public double getFadeOutDuration() {
        return nFadeOutDuration(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 获取音量
     * @return 音量
     */
    public float getVolume() {
        return nVolume(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 获取音频播放速度
     * @return 倍速
     */
    public float getSpeed() {
        return nSpeed(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 获取音调
     * @return 音调
     */
    public float getPitch() {
        return nPitch(mNativeManager, mOwnType.value, mTrackID);
    }

    native static void nSetFadeInDuration(long nativeManager, int type, String audioId, double fadeIn);
    native static void nSetFadeOutDuration(long nativeManager, int type, String audioId, double fadeOut);
    native static void nSetVolume(long nativeManager, int type,  String audioId, float volume);
    native static void nSetSpeed(long nativeManager, int type,  String audioId, float speed);
    native static void nSetPitch(long nativeManager, int type, String audioId, float pitch);

    native static double nFadeInDuration(long nativeManager, int type, String audioId);
    native static double nFadeOutDuration(long nativeManager, int type, String audioId);
    native static float nVolume(long nativeManager, int type, String audioId);
    native static float nSpeed(long nativeManager, int type, String audioId);
    native static float nPitch(long nativeManager, int type, String audioId);
}
