package com.shixing.sxedit;

import com.shixing.sxedit.types.SXBlendMode;
import com.shixing.sxedit.util.TextUtils;

/**
 * 媒体轨道
 *
 * */

public class SXMediaTrack extends SXRenderTrack {
    private SXShape mShape;

    public SXMediaTrack(long track, long manager, SXTrackOwnType type) {
        super(track, manager, type);
    }

    /**
     * 设置变速
     *
     * @param speed, 速度
     * */
    public void setSpeed(double speed) {
        if (mNativeManager > 0) {
            nSetSpeed(mNativeManager, mOwnType.value, mTrackID, speed);
        }
    }

    /**
     * 获取变速
     *
     * @return double
     * */
    public double getSpeed() {
        if (mNativeManager > 0) {
            return nSpeed(mNativeManager, mOwnType.value, mTrackID);
        }
        return 0;
    }

    /**
     * 设置混合模式
     *
     * @param  blendMode, {@link SXBlendMode}
     * */
    public void setBlendMode(SXBlendMode blendMode) {
        if (mNativeManager > 0) {
            nSetBlendMode(mNativeManager, mOwnType.value, mTrackID, blendMode.value);
        }
    }

    /**
     * 获取混合模式
     *
     * @return {@link SXBlendMode}
     * */
    public SXBlendMode getBlendMode() {
        int mode = nBlendMode(mNativeManager, mOwnType.value, mTrackID);
        for (SXBlendMode blendMode : SXBlendMode.values()) {
            if (blendMode.value == mode) {
                return blendMode;
            }
        }
        return SXBlendMode.Normal;
    }

    /**
     * 是否是图片
     *
     * @return boolean
     * */
    public boolean isStaticImage() {
        return nIsStaticImage(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 设置裁剪画中画画面
     *
     * @param width, 宽度
     * @param height, 高度
     * @param transform, 变换矩阵
     *
     * */
    public void setCropData(int width, int height, float[] transform) {
        nSetCropData(mNativeManager, mOwnType.value, mTrackID, width, height, transform);
    }


    /**
     * 设置静止的时间点
     *
     * @param time, 时间点,单位: 秒
     * */
    public void setFreezeTime(double time) {
        nSetFreezeTime(mNativeManager, mOwnType.value, mTrackID, time);
    }

    /**
     * 获取静止的时间点
     *
     * @return double, 静止的时间点, 单位: 秒
     * */
    public double getFreezeTime() {
        return nFreezeTime(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 取消静止
     *
     * */
    public void cancelFreeze() {
        nCancelFreeze(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 设置蒙版形状，删除蒙版传null
     *
     * @param shape 蒙版形状
     */
    public void setMaskShape(SXShape shape) {
        if (shape != null) {
            nSetMaskShape(mNativeManager, mOwnType.value, mTrackID, shape.mNativeShape);
        } else {
            nSetMaskShape(mNativeManager, mOwnType.value, mTrackID, 0);
        }
    }

    /**
     * 当前轨道是否使用翻转的蒙版
     *
     * @return 如果使用翻转的蒙版返回true
     */
    public boolean isInverseMaskShape() {
        return nIsInverseMaskShape(mNativeManager, mOwnType.value, mTrackID);
    }

    /**
     * 设置是否反转蒙版区域
     *
     * @param inverse true：反转，false：不反转
     */
    public void setInverseMaskShape(boolean inverse) {
        nSetInverseMaskShape(mNativeManager, mOwnType.value, mTrackID, inverse);
    }

    /**
     * 获取轨道当前使用的蒙版
     *
     * @return 当前使用的蒙版形状
     */
    public SXShape getMaskShape() {
        long nShape = nMaskShape(mNativeManager, mOwnType.value, mTrackID);
        if (nShape != 0) {
            if (mShape == null || mShape.mNativeShape != nShape) {
                mShape = new SXShape(nShape);
            }
            return mShape;
        }
        return null;
    }

    /**
     * 删除轨道蒙版
     * */
    public void removeMaskShape() {
        if (mNativeManager > 0) {
            nRemoveMaskShape(mNativeManager, mOwnType.value, mTrackID);
        }
    }

    /**
     * 设置轨道蒙版变换
     *
     * @param  trans, 变换矩阵数组
     * */
    public void setMaskTransform(float[] trans) {
        if (mNativeManager > 0) {
            nSetMaskTransform(mNativeManager, mOwnType.value, mTrackID, trans);
        }
    }
    /**
     * 获取轨道蒙版变换矩阵
     *
     * @return float[], 数组
     * */
    public float[] getMaskTransform() {
        if (mNativeManager > 0) {
            return nMaskTransform(mNativeManager, mOwnType.value, mTrackID);
        }
        return null;
    }

    /**
     * 获取使用的素材对象
     *
     * @return SXResource
     * */
    public SXResource getResource() {
        if (mNativeManager > 0) {
            return new SXResource(nResource(mNativeManager, mOwnType.value, mTrackID));
        }
        return null;
    }

    /**
     * 获取关联的音频
     *
     * <p>
     *     只有通过视频文件创建的 {@link SXMediaTrack} 能获取到
     * </p>
     *
     * @return SXAudio
     * */
    public SXAudio getAudio() {
        if (mNativeManager > 0) {
            return new SXAudio(mTrackID, mNativeManager, mOwnType);
        }
        return null;
    }


    /**
     * 设置倒播
     *
     * @param enable    true：倒播     false：不倒播
     */
    public void setPlayBack(boolean enable) {
        if (mNativeManager > 0) {
            nSetPlayBack(mNativeManager, mTrackID, mOwnType.value, enable);
        }
    }

    /**
     * 当前轨道是否倒播
     *
     * @return      true：倒播     false：不倒播
     */
    public boolean isPlayBack() {
        if (mNativeManager > 0) {
            return nIsPlayBack(mNativeManager, mOwnType.value, mTrackID);
        }
        return false;
    }


    /** SXVEMediaTrack **/
    static native void nSetBlendMode(long nativeManager, int type, String trackID, int blendMode);
    static native int nBlendMode(long nativeManager,int type, String trackID);

    native static void nSetSpeed(long nativeManager,int type, String trackId, double speed);
    native static double nSpeed(long nativeManager,int type, String trackId);

    static native void nSetMaskShape(long nativeManager, int type, String trackId, long shape);
    static native long nMaskShape(long nativeManager, int type, String trackId);
    static native void nSetInverseMaskShape(long nativeManager, int type, String trackID, boolean inverse);
    static native boolean nIsInverseMaskShape(long nativeManager, int type, String trackID);
    static native void nRemoveMaskShape(long nativeManager, int type, String trackId);
    static native void nSetMaskTransform(long nativeManager, int type, String trackId, float[] arr);
    static native float[] nMaskTransform(long nativeManager, int type, String trackId);

    static native long nResource(long nativeManager, int type,String trackId);
    static native long nMediaAudio(long nativeManager,int type, String trackId);

    static native boolean nIsStaticImage(long nativeManager,int type, String trackID);
    static native void nSetCropData(long nativeManager,int type, String trackID, int width, int height, float[] transform);

    native static void nSetFreezeTime(long nativeManager,int type, String trackId, double time);
    native static void nCancelFreeze(long nativeManager,int type, String trackId);
    native static double nFreezeTime(long nativeManager,int type, String trackId);

    static native void nSetPlayBack(long nativeManager, String trackId, int type, boolean enable);
    static native boolean nIsPlayBack(long nativeManager, int type, String trackId);
}
