package com.shixing.sxedit.task;

import com.shixing.sxedit.SXEditManager;
import com.shixing.sxedit.SXErrorCode;

/**
 * 剪辑任务渲染类
 * <p>
 *      用于渲染剪辑类，输出一个视频
 * </p>
 * */

public class SXRenderEditTask {
    private long mNativeTask = 0;
    private int mRenderMode = 0; // 0 进程模式

    SXEditRenderListener listener = null;

    /**
     * 剪辑任务渲染类
     *
     * <p>
     *     1. 务必调用 destroy 方法释放任务
     *
     *
     * @param editor 剪辑管理器对象
     * @param outputPath 输出文件路径
     * */
    public SXRenderEditTask(SXEditManager editor, String outputPath) {
        mNativeTask = nCreateRenderTask(editor.getNativeManager(), outputPath);
    }

    /**
     * 渲染任务是否初始化成功
     *
     * @return boolean
     * */
    public boolean isValid() {
        return mNativeTask > 0;
    }

    /**
     * 设置输出视频码率控制参数
     *
     * <p>
     *     1. 最终视频码率 = 宽 * 高 * fps * bitrateControl
     * </p>
     *
     * @param bitrateControl 码率控制参数, 默认 0.25
     * @return boolean
     * */
    public boolean setBitrateControl(float bitrateControl) {
        if (mNativeTask > 0) {
            return nSetBitrateControl(mNativeTask, bitrateControl);
        }
        return false;
    }
    /**
     * 开始渲染
     *
     * <p>
     * 1. 调用此方法时, 会 fork 一个子进程进行渲染
     * <p>
     * 2. 渲染时,有两种方式获取渲染结果
     *      1. 等待该方法返回的错误码 {@link com.shixing.sxedit.SXErrorCode}
     *      2. 设置事件监听器 {@link SXEditRenderListener}
     *
     * @return 错误码， {@link SXErrorCode}
     * */
    public int startRender() {
        if( mRenderMode ==0) {
            return nSaveVideoInProcess(mNativeTask, this.listener);
        }
        return SXErrorCode.SX_CODE_FAIL;
    }

    /**
     * 设置回调监听器
     *
     * @param listener {@link SXEditRenderListener}
     * */
    public void setListener(SXEditRenderListener listener) {
        this.listener = listener;
    }
    /**
     * 获取渲染进度
     *
     * @return float
     * */
    public float getProgress() {
        return nGetProgress(mNativeTask);
    }

    /**
     * 获取错误码
     *
     * @return int
     * */
    public int getError() {
        return nGetError(mNativeTask);
    }

    /**
     * 释放任务对象
     * */
    public void destroy() {
        nDeleteRenderTask(mNativeTask);
    }

    static native long nCreateRenderTask(long nativeManager, String outputPath);
    static native long nDeleteRenderTask(long nativeTask);
    static native boolean nSetBitrateControl(long nativeTask, float bitrateControl);

    static native int nSaveVideoInProcess(long nativeTask, Object listener);
    static native float nGetProgress(long nativeTask);
    static native int nGetError(long nativeTask);

    //    /**
//     * 设置 OpenGL Context
//     * */
//    public void setGLContext(long nativeContext) {
//        nSetGLContext(mNativeTask, nativeContext);
//    }
//
//    /**
//     * 创建 OpenGL Context
//     * */
//    public static long createGLContext(long width, long height) {
//       return nCreateGLContext(width, height);
//    }
//
//    /**
//     * make OpenGL Context current
//     * */
//    public static boolean glContextMakeCurrent(long context) {
//        return nGLContextMakeCurrent(context);
//    }
//
//    /**
//     * 释放 OpenGL Context
//     * */
//    public static void glContextDoneUse(long context) {
//        nGLContextDoneUse(context);
//    }
//    static native int nSetGLContext(long nativeTask, long nativeContext);
//    static native long nCreateGLContext(long width, long height);
//    static native boolean nGLContextMakeCurrent(long nativeContext);
//    static native void nGLContextDoneUse(long nativeContext);
//    static native int nSaveVideo(long nativeTask);
}
